@@ -100,7 +100,7 @@ CallTreeDlg* CallTreeManager::addDialog()
 	CallTreeDlg* pDlg;
 	
 	// Create a modeless call tree dialogue
-	pDlg = new CallTreeDlg((QWidget*)parent());
+	pDlg = new CallTreeDlg();
 	m_lstDialogs.append(pDlg); 
 	
 	// Open an editor whenever a function name is double-clicked
