@@ -109,10 +109,12 @@ bool CscopeFrontend::run(const QStringList& slArgs)
  * to the stndard input of the currently running Cscope process.
  * @param	nType		The type of query to run
  * @param	sText		The query's text
+ * @param	bCase		true for case-sensitive queries, false otherwise
  * @param	nMaxRecords	The maximal number of records to return (abort if this
  *						number is exceeded)
  */
-void CscopeFrontend::query(uint nType, const QString& sText, uint nMaxRecords)
+void CscopeFrontend::query(uint nType, const QString& sText, bool bCase, 
+	uint nMaxRecords)
 {
 	QString sQuery;
 	QStringList slArgs;
@@ -123,7 +125,9 @@ void CscopeFrontend::query(uint nType, const QString& sText, uint nMaxRecords)
 	slArgs.append(QString("-L") + QString::number(nType));
 	slArgs.append(sText);
 	slArgs.append("-d");
-	
+	if (!bCase)
+		slArgs.append("-C");
+		
 	run(slArgs);
 	
 	// Initialise stdout parsing
@@ -389,8 +393,6 @@ CscopeProgress::CscopeProgress(QWidget* pMainWidget) : QObject(),
  */
 CscopeProgress::~CscopeProgress()
 {
-	delete m_pProgressBar;
-	delete m_pLabel;
 }
 
 /**
