@@ -104,6 +104,8 @@ bool DotFrontend::verify(const QString& sPath)
 	return true;
 }
 
+#define PAD	5
+
 /**
  * Parses the output of a Dot process.
  * @param	sToken	The current token read (the token delimiter is determined
@@ -139,7 +141,7 @@ Frontend::ParseResult DotFrontend::parseStdout(QString& sToken,
 		// Read and transform the graph's width
 		dVal = sToken.toDouble(&bOK);
 		if (bOK) {
-			nWidth = (int)(dVal * m_dDpiX);
+			nWidth = (int)(dVal * m_dDpiX) + (PAD * 2);
 			m_state = GraphHeight;
 		}
 		break;
@@ -148,7 +150,7 @@ Frontend::ParseResult DotFrontend::parseStdout(QString& sToken,
 		// Read and transform the graph's height
 		dVal = sToken.toDouble(&bOK);
 		if (bOK) {
-			nHeight = (int)(dVal * m_dDpiY);
+			nHeight = (int)(dVal * m_dDpiY) + (PAD * 2);
 			
 			// Set the graph's size
 			m_pGraph->resize(nWidth, nHeight);
@@ -182,7 +184,7 @@ Frontend::ParseResult DotFrontend::parseStdout(QString& sToken,
 		// Read and transform the node's centre location (X coordinate)
 		dVal = sToken.toDouble(&bOK);
 		if (bOK) {
-			nXpos = (int)(dVal * m_dDpiX);
+			nXpos = (int)(dVal * m_dDpiX) + PAD;
 			m_state = NodeCentreY;
 		}
 		break;
@@ -191,7 +193,7 @@ Frontend::ParseResult DotFrontend::parseStdout(QString& sToken,
 		// Read and transform the node's centre location (Y coordinate)
 		dVal = sToken.toDouble(&bOK);
 		if (bOK) {
-			nYpos = (int)(dVal * m_dDpiY);
+			nYpos = (int)(dVal * m_dDpiY) + PAD;
 			m_state = NodeWidth;
 		}
 		break;
@@ -251,7 +253,7 @@ Frontend::ParseResult DotFrontend::parseStdout(QString& sToken,
 		// Read and a control point (X coordinate)
 		dVal = sToken.toDouble(&bOK);
 		if (bOK) {
-			nXpos = (int)(dVal * m_dDpiX);
+			nXpos = (int)(dVal * m_dDpiX) + PAD;
 			m_state = EdgeCurveY;
 		}
 		break;
@@ -260,7 +262,7 @@ Frontend::ParseResult DotFrontend::parseStdout(QString& sToken,
 		// Read and a control point (Y coordinate)
 		dVal = sToken.toDouble(&bOK);
 		if (bOK) {
-			nYpos = (int)(dVal * m_dDpiY);
+			nYpos = (int)(dVal * m_dDpiY) + PAD;
 			
 			// Add the control point to the spline array
 			arrCurve.setPoint(nCurveCount++, nXpos, nYpos);
