@@ -57,7 +57,6 @@ EditorPage::EditorPage(KTextEditor::Document* pDoc, QPopupMenu* pMenu,
 {
 	KTextEditor::PopupMenuInterface* pMenuIf;
 	KTextEditor::ViewCursorInterface* pCursorIf;
-	KTextEditor::MarkInterfaceExtension* pMarkIf;
 	
 	// Create code-completion objects (will be deleted by QObject destructor)
 	m_pCompletion = new SymbolCompletion(this, this);
@@ -106,15 +105,6 @@ EditorPage::EditorPage(KTextEditor::Document* pDoc, QPopupMenu* pMenu,
 		connect(m_pView, SIGNAL(cursorPositionChanged()), this,
 			SLOT(slotCursorPosChange()));
 	}
-	
-	// Monitor bookmarks
-	pMarkIf = dynamic_cast<KTextEditor::MarkInterfaceExtension*>(m_pDoc);
-	if (pMarkIf) {
-		connect(m_pDoc, SIGNAL(markChanged(KTextEditor::Mark, 
-			KTextEditor::MarkInterfaceExtension::MarkChangeAction)), this,
-			SLOT(slotMarkChanged(KTextEditor::Mark,
-			KTextEditor::MarkInterfaceExtension::MarkChangeAction)));
-	}
 }
 
 /**
@@ -286,6 +276,28 @@ void EditorPage::addBookmark(uint nLine)
 		pMarkIf->setMark(nLine, KTextEditor::MarkInterface::markType01);
 }
 
+/**
+ * Retrieves a list of all bookmarks in this page.
+ */
+void EditorPage::getBookmarks(FileLocationList& fll)
+{
+	KTextEditor::MarkInterface* pMarkIf;
+	QPtrList<KTextEditor::Mark> plMarks;
+	KTextEditor::Mark* pMark;
+	
+	// Get the marks interface
+	pMarkIf = dynamic_cast<KTextEditor::MarkInterface*>(m_pDoc);
+	if (!pMarkIf)
+		return;
+	
+	// Find all bookmarks
+	plMarks = pMarkIf->marks();
+	for (pMark = plMarks.first(); pMark; pMark = plMarks.next()) {
+		if (pMark->type == KTextEditor::MarkInterface::markType01)
+			fll.append(new FileLocation(getFilePath(), pMark->line, 0));
+	}
+}
+
 /**
  * Returns the currently selected text in an open file.
  * @return	The selected text, or a null string if no text is currently
@@ -622,7 +634,7 @@ void EditorPage::slotFileOpened()
 
 	// Check if this is a modified file that has just been saved
 	if (m_bModified)
-		emit fileSaved(m_pDoc->url().path());
+		emit fileSaved(m_pDoc->url().path(), m_bNewFile);
 	
 	// Notify that the document has loaded
 	m_bOpen = true;
@@ -705,24 +717,4 @@ void EditorPage::slotCursorPosChange()
 	m_pCompletion->abort();
 }
 
-/**
- * Called when a mark is added or removed.
- * If the changed mark is a bookmark, the bookmarkChanged() signal is emitted.
- * This slot is connected to the markChanged() signal of the document object.
- * @param	mark	The changed mark
- * @param	act		Whether the mark was added or removed
- */
-void EditorPage::slotMarkChanged(KTextEditor::Mark mark,
-	KTextEditor::MarkInterfaceExtension::MarkChangeAction act)
-{
-	uint nLine;
-	
-	if (mark.type == KTextEditor::MarkInterface::markType01) {
-		nLine = mark.line + 1; // Convert to 1-based line numbers
-		emit bookmarkChanged(m_pDoc->url().path(), nLine,
-			getLineContents(nLine),
-			act == KTextEditor::MarkInterfaceExtension::MarkAdded);
-	}
-}
-
 #include "editorpage.moc"
