@@ -38,6 +38,8 @@ HistoryView::HistoryView(QWidget* pParent, const char* szName) :
 	// Disable sorting
 	setSortColumn(-1);
 	
+	// Don't show the "Function" column
+	setColumnWidthMode(0, QListView::Manual);
 	setColumnWidth(0, 0);
 }
 
