@@ -268,7 +268,7 @@ bool KScope::queryClose()
 	bResult = slotCloseProject();
 	m_bUpdateGUI = true;
 
-	return true;
+	return bResult;
 }
 
 /**
@@ -280,7 +280,8 @@ void KScope::slotCreateProject()
 {
 	NewProjectDlg dlg(true, this);
 	ProjectBase::Options opt;
-
+	QString sProjPath;
+	
 	// Prompt the user to close any active projects
 	if (m_pProjMgr->curProject()) {
 		if (KMessageBox::questionYesNo(0, 
@@ -299,12 +300,10 @@ void KScope::slotCreateProject()
 	if (dlg.exec() != QDialog::Accepted)
 		return;
 
-	// Create the new project
+	// Create and open the new project
 	dlg.getOptions(opt);
-	m_pProjMgr->create(dlg.getName(), dlg.getPath(), opt);
-
-	// Open the project
-	openProject(dlg.getPath() + "/" + dlg.getName());
+	if (m_pProjMgr->create(dlg.getName(), dlg.getPath(), opt, sProjPath))
+		openProject(sProjPath);
 }
 
 /**
