@@ -168,7 +168,7 @@ private:
 	
 	void initMainWindow();
 	void initCscope();
-	bool getSymbol(uint&, QString&, bool bPrompt = true);
+	bool getSymbol(uint&, QString&, bool&, bool bPrompt = true);
 	EditorPage* addEditor(const QString&s);
 	EditorPage* createEditorPage();
 	inline bool isAutoRebuildEnabled();
