@@ -83,7 +83,6 @@ const ElementInfo eiFonts[] = {
 
 KScopeConfig::ConfParams KScopeConfig::s_cpDef = {
 	"/usr/bin/cscope", // Cscope path
-	true, // Verbose flag for Cscope
 	"/usr/bin/ctags", // Ctags path
 	"/usr/bin/dot", // Dot path
 	true, // Show the tag list
@@ -154,8 +153,6 @@ void KScopeConfig::load()
 	// Read the paths to required executables
 	pConf->setGroup("Programs");
 	m_cp.sCscopePath = pConf->readEntry("CScope");
-	m_cp.bVerboseCscope = pConf->readBoolEntry("VerboseCScope",
-		s_cpDef.bVerboseCscope);
 	m_cp.sCtagsPath = pConf->readEntry("CTags");
 	m_cp.sDotPath = pConf->readEntry("Dot");
 
@@ -245,7 +242,6 @@ void KScopeConfig::store()
 	// Write the paths to required executables
 	pConf->setGroup("Programs");
 	pConf->writeEntry("CScope", m_cp.sCscopePath);
-	pConf->writeEntry("VerboseCScope", m_cp.bVerboseCscope);
 	pConf->writeEntry("CTags", m_cp.sCtagsPath);
 	pConf->writeEntry("Dot", m_cp.sDotPath);
 
@@ -347,23 +343,6 @@ void KScopeConfig::setCscopePath(const QString& sPath)
 	m_cp.sCscopePath = sPath;
 }
 
-/**
- * @return	true to use the '-v' option for Cscope, false otherwise
- */
-bool KScopeConfig::useVerboseCscope() const
-{
-	return m_cp.bVerboseCscope;
-}
-
-/**
- * @param	bVerbose	true to use the '-v' option for Cscope, false
- *						otherwise
- */
-void KScopeConfig::setVerboseCscope(bool bVerbose)
-{
-	m_cp.bVerboseCscope = bVerbose;
-}
-
 /**
  * @return	The full path of the Ctags executable
  */
@@ -637,7 +616,7 @@ bool KScopeConfig::getAutoSortFiles()
 }
 
 /**
- * @param	bWarn	true to sort files when a project is loaded, false 
+ * @param	bSort	true to sort files when a project is loaded, false 
  *					otherwise
  */
 void KScopeConfig::setAutoSortFiles(bool bSort)
