@@ -83,8 +83,6 @@ public:
 	
 	const QString& getCscopePath() const;
 	void setCscopePath(const QString&);
-	bool useVerboseCscope() const;
-	void setVerboseCscope(bool);
 	const QString& getCtagsPath() const;
 	void setCtagsPath(const QString&);
 	const QString& getDotPath() const;
@@ -141,9 +139,6 @@ private:
 		/** The full path of the Cscope executable. */
 		QString sCscopePath;
 		
-		/** Whether the '-v' flag should be used with Cscope. */
-		bool bVerboseCscope;
-		
 		/** The full path of the Ctags executable. */
 		QString sCtagsPath;
 		
