@@ -193,6 +193,24 @@ static const char* XPM_LABEL[] = {
 	"............"
 };
 
+static const char* XPM_INCLUDE[] = {
+	"12 12 2 1",
+	". c #000000",
+	"# c #c0c0c0",
+	"............",
+	".##########.",
+	".##.....###.",
+	".####.#####.",
+	".####.#####.",
+	".####.#####.",
+	".####.#####.",
+	".####.#####.",
+	".####.#####.",
+	".##.....###.",
+	".##########.",
+	"............"
+};
+
 static const char* XPM_UNKNOWN[] = {
 	"12 12 2 1",
 	". c #000000",
@@ -254,6 +272,7 @@ void KScopePixmaps::init()
 	m_pPixArray[SymEnumerator] = new QPixmap(XPM_ENUMERATOR);
 	m_pPixArray[SymTypedef] = new QPixmap(XPM_TYPEDEF);
 	m_pPixArray[SymLabel] = new QPixmap(XPM_LABEL);
+	m_pPixArray[SymInclude] = new QPixmap(XPM_INCLUDE);
 	m_pPixArray[SymUnknown] = new QPixmap(XPM_UNKNOWN);
 }
 
@@ -283,6 +302,10 @@ QPixmap KScopePixmaps::getPixmap(LoadPixName name)
 		return m_loader.loadIcon("query_locked", KIcon::Small, 0,
 			false);
 
+	case TabBookmark:
+		return m_loader.loadIcon("bookmark", KIcon::Small, 0,
+			false);
+
 	case TabRW:
 		return m_loader.loadIcon("file_rw", KIcon::Small, 0,
 			false);
