@@ -25,6 +25,7 @@
  *
  ***************************************************************************/
 
+#include <qtextcodec.h>
 #include <ktextbrowser.h>
 #include <kcombobox.h>
 #include <kurlrequester.h>
@@ -49,6 +50,7 @@ MakeDlg::MakeDlg(QWidget* pParent, const char* szName) :
 	MakeLayout(pParent, szName, MAKE_DLG_W_FLAGS)
 {
 	// Don't show the "Function" column
+	m_pErrorView->setColumnWidthMode(0, QListView::Manual);
 	m_pErrorView->setColumnWidth(0, 0);
 	
 	// Create a new make front-end
@@ -196,7 +198,12 @@ void MakeDlg::slotStop()
  */
 void MakeDlg::slotShowOutput(FrontendToken* pToken)
 {
-	m_pOutputBrowser->append(pToken->getData());
+	QString sData;
+	
+	// GCC uses unicode quote characters - this should ensure that they are
+	// treated correctly by the text browser widget
+	sData = QTextCodec::codecForLocale()->toUnicode(pToken->getData());
+	m_pOutputBrowser->append(sData);
 }
 
 /**
@@ -241,10 +248,20 @@ void MakeDlg::slotBrowserClicked(const QString& sURL)
 	emit fileRequested(sFile, sLine.toUInt());
 }
 
+/**
+ * Show an error/warning on a deidicated list.
+ * This slot is connected to the error() signal of the make front-end.
+ * @param	sFile	The file name containing the error/warning
+ * @param	sLine	The line number
+ * @param	sText	An explanation of the error
+ */
 void MakeDlg::slotAddError(const QString& sFile, const QString& sLine,
 	const QString& sText)
 {
-	m_pErrorView->addRecord("", sFile, sLine, sText);
+	QString sUniText;
+	
+	sUniText = QTextCodec::codecForLocale()->toUnicode(sText);
+	m_pErrorView->addRecord("", sFile, sLine, sUniText);
 }
 	
 #include "makedlg.moc"
