@@ -157,6 +157,9 @@ QString NewProjectDlg::getName()
  */
 QString NewProjectDlg::getPath()
 {
+	if (m_pHiddenDirCheck->isChecked())
+		return QString(m_pSrcRootRequester->url()) + "/.cscope";
+	
 	return m_pPathRequester->url();
 }
 
