@@ -146,11 +146,11 @@ bool PreferencesDlg::updateConfig()
 
 /**
  * Tests whether the paths set for Cscope and Ctags lead to executables.
+ * Cscope is verified by a different process.
  */
 bool PreferencesDlg::verifyPaths()
 {
-	return (CscopeFrontend::verify(m_pPrefFrontend->m_pCscopeURL->url()) &&
-		CtagsFrontend::verify(m_pPrefFrontend->m_pCtagsURL->url()) &&
+	return (CtagsFrontend::verify(m_pPrefFrontend->m_pCtagsURL->url()) &&
 		DotFrontend::verify(m_pPrefFrontend->m_pDotURL->url()));
 }
 
