@@ -43,10 +43,10 @@
  * @param	pParent		The parent widget
  * @param	szName		The widget's name
  */
-ProjectFilesDlg::ProjectFilesDlg(ProjectManager* pProjMgr, QWidget* pParent,
+ProjectFilesDlg::ProjectFilesDlg(Project* pProj, QWidget* pParent,
 	const char* szName) :
 	ProjectFilesLayout(pParent, szName),
-	m_pProjMgr(pProjMgr),
+	m_pProj(pProj),
 	m_pScanDlg(NULL),
 	m_pItrItem(NULL),
 	m_pLastItem(NULL)
@@ -86,7 +86,7 @@ ProjectFilesDlg::ProjectFilesDlg(ProjectManager* pProjMgr, QWidget* pParent,
 
 	// Fill the list with the project's files
 	m_pFileList->setUpdatesEnabled(false);
-	m_pProjMgr->fillList(this);
+	m_pProj->loadFileList(this);
 	m_pFileList->setUpdatesEnabled(true);
 	m_pFileList->triggerUpdate();
 }
@@ -232,14 +232,10 @@ void ProjectFilesDlg::slotAddFiles()
 {
 	QStringList slFiles;
 	QStringList::const_iterator itr;
-	
-	// A project must be open
-	if (!m_pProjMgr->isOpen())
-		return;
 
 	// Prompt the user
-	slFiles = KFileDialog::getOpenFileNames(QString::null,
-		m_pProjMgr->getFileTypes());
+	slFiles = KFileDialog::getOpenFileNames(m_pProj->getSourceRoot(),
+		m_pProj->getFileTypes());
 
 	// Add the selected files, skipping existing entries
 	for (itr = slFiles.begin(); itr != slFiles.end(); ++itr) {
@@ -261,17 +257,13 @@ void ProjectFilesDlg::slotAddDir()
 	QStringList slFiles;
 	QStringList::const_iterator itr;
 
-	// A project must be open
-	if (!m_pProjMgr->isOpen())
-		return;
-
 	// Prompt the user for a directory
-	sDir = KFileDialog::getExistingDirectory();
+	sDir = KFileDialog::getExistingDirectory(m_pProj->getSourceRoot());
 	if (sDir.isEmpty())
 		return;
 
 	// Search for source files in this directory
-	m_pScanner->start(sDir, m_pProjMgr->getFileTypes(), false);
+	m_pScanner->start(sDir, m_pProj->getFileTypes(), false);
 }
 
 /**
@@ -287,17 +279,13 @@ void ProjectFilesDlg::slotAddTree()
 	QStringList slFiles;
 	QStringList::const_iterator itr;
 
-	// A project must be open
-	if (!m_pProjMgr->isOpen())
-		return;
-
 	// Prompt the user for a directory
-	sDir = KFileDialog::getExistingDirectory();
+	sDir = KFileDialog::getExistingDirectory(m_pProj->getSourceRoot());
 	if (sDir.isEmpty())
 		return;
 
 	// Search for source files in this directory
-	m_pScanner->start(sDir, m_pProjMgr->getFileTypes(), true);
+	m_pScanner->start(sDir, m_pProj->getFileTypes(), true);
 }
 
 /**
@@ -333,7 +321,7 @@ void ProjectFilesDlg::slotRemDir()
 	QListViewItem* pItem, * pPrevItem;
 
 	// Prompt the user for a directory
-	sDir = KFileDialog::getExistingDirectory();
+	sDir = KFileDialog::getExistingDirectory(m_pProj->getSourceRoot());
 	if (sDir.isEmpty())
 		return;
 		
@@ -366,7 +354,7 @@ void ProjectFilesDlg::slotRemTree()
 	QListViewItem* pItem, * pPrevItem;
 
 	// Prompt the user for a directory
-	sDir = KFileDialog::getExistingDirectory();
+	sDir = KFileDialog::getExistingDirectory(m_pProj->getSourceRoot());
 	if (sDir.isEmpty())
 		return;
 
