@@ -39,7 +39,8 @@ public:
 	ProjectManager();
 	virtual ~ProjectManager();
 	
-	bool create(const QString&, const QString&, const ProjectBase::Options&);
+	bool create(const QString&, const QString&, const ProjectBase::Options&,
+		QString&);
 	bool open(const QString&);
 	bool openCscopeOut(const QString&);
 	void close();
