@@ -71,17 +71,29 @@ QueryPage::~QueryPage()
 }
 
 /**
- * Associates the page with a query's type and text.
+ * Runs a query, using the current page to display the results.
  * @param	nType	The type of the query
  * @param	sText	The text of the query
+ * @param	bCase		true for case-sensitive queries, false otherwise
  */
-void QueryPage::query(uint nType, const QString& sText)
+void QueryPage::query(uint nType, const QString& sText, bool bCase)
 {
 	m_nType = nType;
 	m_sText = sText;
+	m_bCase = bCase;
 	m_sName = getCaption();
 	
-	m_pDriver->query(nType, sText);
+	m_pDriver->query(nType, sText, bCase);
+}
+
+/**
+ * Re-runs the last query.
+ */
+void QueryPage::refresh()
+{
+	m_pView->clear();
+	if (!m_sText.isEmpty())
+		m_pDriver->query(m_nType, m_sText, m_bCase);
 }
 
 /**
