@@ -50,22 +50,12 @@ public:
 	QueryPage(QWidget* pParent = 0, const char* szName = 0);
 	~QueryPage();
 	
-	void query(uint, const QString&);
+	void query(uint, const QString&, bool);
+	void refresh();
 	void clear();
 	bool isRunning();
 	
 	virtual QString getCaption(bool bBrief = false) const;
-	
-	/**
-	 * @return	The type of query whose results are displayed in this page
-	 */
-	uint getQueryType() const { return m_nType; }
-	
-	/**
-	 * @return	The text given as a parameter to the query whose results are
-	 * displayed in this page.
-	 */
-	const QString& getQueryText() const { return m_sText; }
 
 protected:
 	virtual void addRecord(const QString&, const QString&, const QString&,
@@ -81,6 +71,9 @@ private:
 	/** The text given as a parameter to the query. */
 	QString m_sText;
 	
+	/** Whether the query is case-sensitive. */
+	bool m_bCase;
+	
 	/** A formatted caption for this query, including the type of query and
 		its text. */
 	QString m_sName;
