@@ -33,6 +33,75 @@
 
 class QueryResultsMenu;
 
+/**
+ * Items in a query view.
+ * The sole purpose for creating a new class is to be able to sort query 
+ * results numerically by line number.
+ * @author Elad Lahav
+ */
+class QueryViewItem : public QListViewItem
+{
+public:
+	/**
+	 * Class constructor.
+	 * Used for list views.
+	 * @param	pView		The view widget
+	 * @param	pAfter		The item to preceed the new one
+	 * @param	nLineCol	The index of the line column
+	 */
+	QueryViewItem(QListView* pView, QListViewItem* pAfter, 
+		int nLineCol) : QListViewItem(pView, pAfter), m_nLineCol(nLineCol)
+		{}
+	
+	/**
+	 * Class constructor.
+	 * Used for tree views.
+	 * @param	pParent		The parent item
+	 * @param	pAfter		The item to preceed the new one
+	 * @param	nLineCol	The index of the line column
+	 */
+	QueryViewItem(QListViewItem* pParent, QListViewItem* pAfter, 
+		int nLineCol) : QListViewItem(pParent, pAfter), m_nLineCol(nLineCol)
+		{}
+	
+	/**
+	 * Compares two items.
+	 * If the given column holds line numbers, than the items are compared
+	 * by their numeric values. Otherwise, a standard text comparison is
+	 * performed.
+	 * @param	pItem	The item to compare to
+	 * @param	nCol	The column by which to compare
+	 * @param	bAscend	Whether sorting in ascending or descending order
+	 * @return	0 if the items are equal, 1 if the current item is greater,
+	 * 			-1 if the current item is smaller
+	 */
+	virtual int compare(QListViewItem* pItem, int nCol, bool bAscend) const {
+		if (nCol == m_nLineCol) {
+			uint nLineCur, nLineOther;
+			int nResult;
+
+			// Get the line numbers of each item
+			nLineCur = text(nCol).toUInt();
+			nLineOther = pItem->text(nCol).toUInt();
+
+			// Compare the line numbers
+			nResult = nLineCur - nLineOther;
+			if (nResult == 0)
+				return 0; // Items are equal
+			else if (nResult > 0)
+				return 1; // The first item is greater
+			else
+				return -1; // The second item is greater
+		}
+		
+		return QListViewItem::compare(pItem, nCol, bAscend);
+	}
+	
+private:
+	/** The index of the column holding the line numbers. */
+	int m_nLineCol;
+};
+
 /**
  * A list view widget for displaying locations in the source code. Each record
  * (list item) represents a single line of code.
