@@ -77,8 +77,9 @@ QueryWidget::~QueryWidget()
  * method then creates a Cscope process and runs the query.
  * @param	nType	The query's numeric type code
  * @param	sText	The query's text, as entered by the user
+ * @param	bCase		true for case-sensitive queries, false otherwise
  */
-void QueryWidget::initQuery(uint nType, const QString& sText)
+void QueryWidget::initQuery(uint nType, const QString& sText, bool bCase)
 {
 	QueryPage* pPage;
 	
@@ -94,7 +95,7 @@ void QueryWidget::initQuery(uint nType, const QString& sText)
 
 	// Reset the page's results list
 	pPage->clear();
-	pPage->query(nType, sText);
+	pPage->query(nType, sText, bCase);
 	
 	// Set the page's tab text according to the new query
 	setPageCaption(pPage);
@@ -274,23 +275,14 @@ void QueryWidget::slotLockCurrent()
 void QueryWidget::slotRefreshCurrent()
 {
 	QueryPage* pPage;
-	uint nType;
-	QString sText;
 	
 	// Make sure the current page is a valid, non-empty one
 	pPage = dynamic_cast<QueryPage*>(currentPage());
-	if ((pPage == NULL) ||
-		(pPage->getQueryType() == CscopeFrontend::None)) {
+	if (pPage == NULL)
 		return;
-	}
-
-	// Get the current page parameters (before they are deleted by clear())
-	nType = pPage->getQueryType();
-	sText = pPage->getQueryText();
 	
 	// Clear the current page contents
-	pPage->clear();
-	pPage->query(nType, sText);
+	pPage->refresh();
 }
 
 /**
