@@ -155,7 +155,7 @@ void TreeWidget::addRecord(const QString& sFunc, const QString& sFile,
 {
 	QListViewItem* pItem;
 	
-	pItem = new QListViewItem(pParent, m_pLastItem);
+	pItem = new QueryViewItem(pParent, m_pLastItem, 2);
 	pItem->setText(0, sFunc);
 	pItem->setText(1, sFile);
 	pItem->setText(2, sLine);
@@ -194,7 +194,7 @@ void TreeWidget::slotQueryItem(QListViewItem* pItem)
 		return;
 		
 	// Run the query
-	m_pDriver->query(m_nQueryType, pItem->text(0), pItem);
+	m_pDriver->query(m_nQueryType, pItem->text(0), true, pItem);
 }
 
 /**
